# Welcome to xinfer


![PyPI version](https://img.shields.io/pypi/v/xinfer.svg?style=for-the-badge&logo=pypi&logoColor=white&label=PyPI&color=blue)
![Downloads](https://img.shields.io/pypi/dm/xinfer.svg?style=for-the-badge&logo=pypi&logoColor=white&label=Downloads&color=purple)
![License](https://img.shields.io/badge/License-Apache%202.0-green.svg?style=for-the-badge&logo=apache&logoColor=white)


**A unified interface to run inference on computer vision libraries.**


-   Free software: Apache Software License 2.0
-   Documentation: <https://dnth.github.io/xinfer>
    

## Features

-   TODO
